@@ -16,7 +16,7 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.104';
+our $VERSION = '0.105';
 
 use Carp qw(croak);
 
@@ -350,7 +350,7 @@ sub find_debs_for_modules {
                     }
                     else {
                         warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
-                            .qq(You may need to install and run "apt update");
+                            .qq(You may need to run "apt-cache dumpavail | dpkg --merge-avail");
                     }
                 } @pkgs;
                 unless ( @satisfied ) {
